@@ -172,7 +172,7 @@ rvn_num_days <- function(date1, date2)
 #' two dates
 #'
 #' See original code on post in Stack Overflow
-#' \href{http://stackoverflow.com/questions/6243088/find-out-the-number-of-days-of-a-month-in-rfind}{
+#' \href{https://stackoverflow.com/questions/6243088/find-out-the-number-of-days-of-a-month-in-rfind}{
 #' the number of days in a month}
 #' @examples
 #'
@@ -306,11 +306,16 @@ rvn_apply_wyearly_which_max_xts <- function(x, mm=9, dd=30)
     xx <- rep(NA,length(ep)-1)
 
     for (i in 1:(length(ep)-1)) {
-      dx[i] <- lubridate::date(x[ep[i]:ep[i+1]])[which.max(x[ep[i]:ep[i+1]])]
-      xx[i] <- as.numeric(x[ep[i]:ep[i+1]][which.max(x[ep[i]:ep[i+1]])])
+      if (length(which.max(x[ep[i]:ep[i+1]]))>=1) {
+        dx[i] <- lubridate::date(x[ep[i]:ep[i+1]])[which.max(x[ep[i]:ep[i+1]])]
+        xx[i] <- as.numeric(x[ep[i]:ep[i+1]][which.max(x[ep[i]:ep[i+1]])])
+      }
     }
 
-    myxts <- xts(xx, order.by=dx)
+    df <- data.frame(xx,dx)
+    df[which(is.na(df$xx)),]$dx <- lubridate::date(x[ep[which(is.na(df$xx))+1]])
+
+    myxts <- xts(df$xx, order.by=df$dx)
     colnames(myxts) <- colnames(x)
     return(myxts)
 
@@ -467,6 +472,31 @@ rvn_stringpad <- function(string, width, just='r', padstring=' ')
   }
 }
 
+#' @title Convert hours, minutes, seconds to decimal hours
+#'
+#' @description
+#' Converts string format HH:MM:SS to decimal hours
+#'
+#' @param x input as character, format HH:MM:SS
+#'
+#' @return {time in decimal hours}
+#'
+#' @examples
+#' # return hour:minutes:seconds to decimal hours
+#' hhmmss2dec("02:35:58")
+#'
+#' @export hhmmss2dec
+hhmmss2dec <- function(x) {
+  # from Stack Overflow:
+  # https://stackoverflow.com/questions/42516233/converting-time-hhmmss-to-decimal-values-in-r
+  xlist <- strsplit(x,split=":")
+  h <- as.numeric(sapply(xlist,"[",1))
+  m <- as.numeric(sapply(xlist,"[",2))
+  s <- as.numeric(sapply(xlist,"[",3))
+  xdec <- h+(m/60)+(s/60/60)
+  return(xdec)
+}
+
 #' @title \%notin\% operator
 #'
 #' @description
@@ -516,7 +546,6 @@ rvn_fortify_xts <- function(x)
   return(y)
 }
 
-
 #' @title Provide known options for Raven rvi options
 #'
 #' @description
@@ -688,7 +717,7 @@ get_rvt_mapping <- function() {
 #' @noRd
 get_rvt_data_type_mapping <- function() {
 
-  # update this based on table C.1 in Raven Manual?
+  # update this based on table D.1 in Raven Manual?
   rvt_data_type_mapping <- list(
     "HYDROGRAPH"=list(
       "units"="m3/s"
@@ -701,9 +730,20 @@ get_rvt_data_type_mapping <- function() {
     ),
     "RESERVOIR_NETINFLOW"=list(
       "units"="m3/s"
+    ),
+    "WATER_LEVEL"=list(
+      "units"="m"
+    ),
+    "STREAM_TEMPERATURE"=list(
+      "units"="dC"
+    ),
+    "STREAM_CONCENTRATION"=list(
+      "units"="mg/L"
+    ),
+    "SNOW"=list(
+      "units"="mm"
     )
   )
-
   return(rvt_data_type_mapping)
 }
 
@@ -765,6 +805,7 @@ get_rvt_met_mapping_weathercan <- function() {
     "TOTAL_SNOW"=list("SNOWFALL"),
     "MAX_TEMP"=list("TEMP_MAX"),
     "MIN_TEMP"=list("TEMP_MIN"),
+    "MEAN_TEMP"=list("TEMP_AVE"),
     "WIND_SPD"=list("WIND_VEL"), # warning on unit conversion
     "REL_HUM"=list("REL_HUMIDITY"),
     "PRECIP_AMT"=list("PRECIP"), # add warning on unit conversion
@@ -789,7 +830,7 @@ get_rvt_met_mapping_weathercan <- function() {
 #'
 #' @param p1 longitude/latitude of point(s); can be a vector of two numbers, or a matrix of 2 columns (long/lat).
 #' @param p2 second point in same format as \code{p1}
-#' @param method calculation method as either \code{haversine} (default) or {vincentysphere}
+#' @param method calculation method as either \code{haversine} (default) or \code{vincentysphere}
 #' @param r radius of the Earth in metres (default 6378137)
 #'
 #' @return a vector of calculated distances (length of vector based on input)
@@ -845,14 +886,17 @@ rvn_dist_lonlat <- function(p1, p2, method="haversine", r=6378137) {
 
 #' @title Determine layout coordinates of labels
 #'
-#' @description Provides the layout data frame based on the supplied vector of named Raven state variables.
+#' @description Provides the layout data frame based on the supplied vector of
+#' named Raven state variables.
 #'
-#' @details
-#' The position is based on the state variable, i.e. soils generally on the bottom, atmosphere at the top, etc.
-#' Unrecognized labels are generally placed on the left hand side of the layout.
+#' @details The position is based on the state variable, i.e. soils generally on
+#' the bottom, atmosphere at the top, etc. Unrecognized labels are generally
+#' placed on the left hand side of the layout.
 #'
 #' @param verts character vector of state variables to be included in the layout
-#' @return \item{layout}{a data frame of verts labels and xy coordinates intended for plotting labels}
+#'
+#' @return \item{layout}{a data frame of verts labels and xy coordinates
+#' intended for plotting labels}
 #'
 #' @noRd
 #' @keywords internal
@@ -903,6 +947,7 @@ rvn_rvi_process_layout <- function(verts) {
 
 #' @title Estimate text grob length
 #'
+#' @description
 #' Estimate the printed length of `resizingTextGrob` text
 #'
 #' @param text The text to be printed (character)
@@ -921,6 +966,7 @@ text_grob_length <- function(text, rot = 0) {
 
 #' @title Bounding box coords for labels
 #'
+#' @description
 #' Given a position, size, rotation, and justification of a label, calculate the bounding box coordinates
 #'
 #' @param label character text of each label
@@ -1005,6 +1051,7 @@ label_bounds <- function(label, x, y, height, rotation, just) {
 
 #' @title Reformat bounding box coords for labels
 #'
+#' @description
 #' Reformat the bounding box coordinates object to have columns for label, xmin, xmax, ymin, ymax.
 #'
 #' @param bounds object returned by \code{label_bounds}
